@@ -11,9 +11,9 @@ use Data::Sah::CoerceCommon;
 use Exporter qw(import);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-09-22'; # DATE
+our $DATE = '2023-10-24'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.053'; # VERSION
+our $VERSION = '0.054'; # VERSION
 
 our @EXPORT_OK = qw(gen_coercer);
 
@@ -148,7 +148,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.053 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2022-09-22.
+This document describes version 0.054 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2023-10-24.
 
 =head1 SYNOPSIS
 
@@ -316,8 +316,6 @@ modules then compose them into the final code, something like (in pseudocode):
    return original data;
  }
 
-=for Pod::Coverage .+
-
 =head1 VARIABLES
 
 =head2 $Log_Coercer_Code => bool (default: from ENV or 0)
@@ -329,6 +327,86 @@ something like:
  % TRACE=1 perl -MLog::ger::LevelFromEnv -MLog::ger::Output=Screen \
      -MData::Sah::Coerce=gen_coercer -E'my $c = gen_coercer(...)'
 
+=head1 FUNCTIONS
+
+
+=head2 gen_coercer
+
+Usage:
+
+ gen_coercer(%args) -> any
+
+Generate coercer code.
+
+This is mostly for testing. Normally the coercion rules will be used from
+L<Data::Sah>.
+
+This function is not exported by default, but exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<coerce_rules> => I<array[str]>
+
+A specification of coercion rules to use (or avoid).
+
+This setting is used to specify which coercion rules to use (or avoid) in a
+flexible way. Each element is a string, in the form of either C<NAME> to mean
+specifically include a rule, or C<!NAME> to exclude a rule.
+
+Some coercion modules are used by default, unless explicitly avoided using the
+'!NAME' rule.
+
+To not use any rules:
+
+To use the default rules plus R1 and R2:
+
+ ['R1', 'R2']
+
+To use the default rules but not R1 and R2:
+
+ ['!R1', '!R2']
+
+=item * B<coerce_to> => I<str>
+
+Some Sah types, like C<date>, can be represented in a choice of types in the
+target language. For example, in Perl you can store it as a floating number
+a.k.a. C<float(epoch)>, or as a L<DateTime> object, or L<Time::Moment>
+object. Storing in DateTime can be convenient for date manipulation but requires
+an overhead of loading the module and storing in a bulky format. The choice is
+yours to make, via this setting.
+
+=item * B<return_type> => I<str> (default: "val")
+
+C<val> means the coercer will return the input (possibly) coerced or undef if
+coercion fails.
+
+C<bool_coerced+val> means the coercer will return a 2-element array. The first
+element is a bool value set to 1 if coercion has been performed or 0 if
+otherwise. The second element is the (possibly) coerced input.
+
+C<bool_coerced+str_errmsg+val> means the coercer will return a 3-element array.
+The first element is a bool value set to 1 if coercion has been performed or 0
+if otherwise. The second element is the error message string which will be set
+if there is a failure in coercion (or undef if coercion is successful). The
+third element is the (possibly) coerced input.
+
+=item * B<source> => I<bool>
+
+If set to true, will return coercer source code string instead of compiled code.
+
+=item * B<type>* => I<sah::type_name>
+
+(No description)
+
+
+=back
+
+Return value:  (any)
+
+=for Pod::Coverage .+
+
 =head1 ENVIRONMENT
 
 =head2 LOG_SAH_COERCER_CODE => bool
@@ -379,7 +457,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2021, 2020, 2019, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
